summaryrefslogtreecommitdiffstats
path: root/compiler/rustc_trait_selection/src/traits/query/dropck_outlives.rs
diff options
context:
space:
mode:
Diffstat (limited to 'compiler/rustc_trait_selection/src/traits/query/dropck_outlives.rs')
-rw-r--r--compiler/rustc_trait_selection/src/traits/query/dropck_outlives.rs24
1 files changed, 12 insertions, 12 deletions
diff --git a/compiler/rustc_trait_selection/src/traits/query/dropck_outlives.rs b/compiler/rustc_trait_selection/src/traits/query/dropck_outlives.rs
index 620b992ee..f8efa6a1f 100644
--- a/compiler/rustc_trait_selection/src/traits/query/dropck_outlives.rs
+++ b/compiler/rustc_trait_selection/src/traits/query/dropck_outlives.rs
@@ -5,7 +5,7 @@ use crate::traits::{Normalized, ObligationCause, ObligationCtxt};
use rustc_data_structures::fx::FxHashSet;
use rustc_middle::traits::query::{DropckConstraint, DropckOutlivesResult};
use rustc_middle::ty::{self, EarlyBinder, ParamEnvAnd, Ty, TyCtxt};
-use rustc_span::source_map::{Span, DUMMY_SP};
+use rustc_span::{Span, DUMMY_SP};
/// This returns true if the type `ty` is "trivial" for
/// dropck-outlives -- that is, if it doesn't require any types to
@@ -35,7 +35,7 @@ pub fn trivial_dropck_outlives<'tcx>(tcx: TyCtxt<'tcx>, ty: Ty<'tcx>) -> bool {
| ty::FnDef(..)
| ty::FnPtr(_)
| ty::Char
- | ty::GeneratorWitness(..)
+ | ty::CoroutineWitness(..)
| ty::RawPtr(_)
| ty::Ref(..)
| ty::Str
@@ -72,7 +72,7 @@ pub fn trivial_dropck_outlives<'tcx>(tcx: TyCtxt<'tcx>, ty: Ty<'tcx>) -> bool {
| ty::Placeholder(..)
| ty::Infer(_)
| ty::Bound(..)
- | ty::Generator(..) => false,
+ | ty::Coroutine(..) => false,
}
}
@@ -216,7 +216,7 @@ pub fn dtorck_constraint_for_ty_inner<'tcx>(
| ty::Ref(..)
| ty::FnDef(..)
| ty::FnPtr(_)
- | ty::GeneratorWitness(..) => {
+ | ty::CoroutineWitness(..) => {
// these types never have a destructor
}
@@ -261,22 +261,22 @@ pub fn dtorck_constraint_for_ty_inner<'tcx>(
})?
}
- ty::Generator(_, args, _movability) => {
+ ty::Coroutine(_, args, _movability) => {
// rust-lang/rust#49918: types can be constructed, stored
// in the interior, and sit idle when generator yields
// (and is subsequently dropped).
//
// It would be nice to descend into interior of a
// generator to determine what effects dropping it might
// have (by looking at any drop effects associated with
// its interior).
//
// However, the interior's representation uses things like
// GeneratorWitness that explicitly assume they are not
// traversed in such a manner. So instead, we will
- // simplify things for now by treating all generators as
+ // simplify things for now by treating all coroutines as
// if they were like trait objects, where its upvars must
// all be alive for the generator's (potential)
// destructor.
//
// In particular, skipping over `_interior` is safe
@@ -284,13 +284,13 @@ pub fn dtorck_constraint_for_ty_inner<'tcx>(
// only take place through references with lifetimes
// derived from lifetimes attached to the upvars and resume
// argument, and we *do* incorporate those here.
- let args = args.as_generator();
+ let args = args.as_coroutine();
if !args.is_valid() {
// By the time this code runs, all type variables ought to
// be fully resolved.
tcx.sess.delay_span_bug(
span,
- format!("upvar_tys for generator not found. Expected capture information for generator {ty}",),
+ format!("upvar_tys for coroutine not found. Expected capture information for coroutine {ty}",),
);
return Err(NoSolution);
}
@@ -261,22 +261,22 @@ pub fn dtorck_constraint_for_ty_inner<'tcx>(
// rust-lang/rust#49918: types can be constructed, stored
- // in the interior, and sit idle when generator yields
+ // in the interior, and sit idle when coroutine yields
// (and is subsequently dropped).
//
@@ -261,22 +261,22 @@ pub fn dtorck_constraint_for_ty_inner<'tcx>(
//
// It would be nice to descend into interior of a
- // generator to determine what effects dropping it might
+ // coroutine to determine what effects dropping it might
// have (by looking at any drop effects associated with
// its interior).
@@ -261,22 +261,22 @@ pub fn dtorck_constraint_for_ty_inner<'tcx>(
//
// However, the interior's representation uses things like
- // GeneratorWitness that explicitly assume they are not
+ // CoroutineWitness that explicitly assume they are not
// traversed in such a manner. So instead, we will
@@ -261,22 +261,22 @@ pub fn dtorck_constraint_for_ty_inner<'tcx>(
// if they were like trait objects, where its upvars must
- // all be alive for the generator's (potential)
+ // all be alive for the coroutine's (potential)
// destructor.
//